@@ -84,7 +84,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57000
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x57000
 #  endif
 #endif
 
